# Changelog

## 1.8.0 (2025-01-01)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/evrimai/python-client/compare/v1.7.0...v1.8.0)

### Features

* **api:** updating API key name ([#31](https://github.com/evrimai/python-client/issues/31)) ([3e015f1](https://github.com/evrimai/python-client/commit/3e015f1a95a4964e0dc292df12b419b6ae3e777a))

## 1.7.0 (2025-01-01)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/evrimai/python-client/compare/v1.6.0...v1.7.0)

### Features

* **api:** api update ([#27](https://github.com/evrimai/python-client/issues/27)) ([8d22185](https://github.com/evrimai/python-client/commit/8d221857439bf828bc872cfc3d7bce02f1c3c0e8))
* **api:** updating URLs ([ffbb66b](https://github.com/evrimai/python-client/commit/ffbb66b945b37a205096b7740ee729abf1c8ad31))
* **api:** updating with v0 slug ([80229ca](https://github.com/evrimai/python-client/commit/80229ca53f0e2ab6b40575afb85aa12df84023f1))
* **api:** updating with v0 slug ([b39a8f0](https://github.com/evrimai/python-client/commit/b39a8f09712e99d44157cf3f53fb887d4f07754e))


### Chores

* go live ([#29](https://github.com/evrimai/python-client/issues/29)) ([908e205](https://github.com/evrimai/python-client/commit/908e205c456a859cf17bcaeea3e94a1acf87ce91))

## 1.6.0 (2024-12-28)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/evrimai/python-client/compare/v1.5.0...v1.6.0)

### Features

* **api:** api update ([#20](https://github.com/evrimai/python-client/issues/20)) ([6ca7d2d](https://github.com/evrimai/python-client/commit/6ca7d2dda02b9578cf2aaa63f230921a64dd18a1))
* **api:** api update ([#24](https://github.com/evrimai/python-client/issues/24)) ([018d672](https://github.com/evrimai/python-client/commit/018d67268af633aa2f6c78090d6c9e7c0bfbc44c))
* **api:** manual updates ([#22](https://github.com/evrimai/python-client/issues/22)) ([38596c2](https://github.com/evrimai/python-client/commit/38596c264a48a77025c49c02b8263cd2b6622b34))
* **api:** manual updates from new auth workflow ([#25](https://github.com/evrimai/python-client/issues/25)) ([557c474](https://github.com/evrimai/python-client/commit/557c4741ba233a0aed027d7cea2df71e098fd4af))
* **api:** updating type to http ([#23](https://github.com/evrimai/python-client/issues/23)) ([6e7dd00](https://github.com/evrimai/python-client/commit/6e7dd0044e10683f2fcfaf715c0f5f92ae36bfc4))

## 1.5.0 (2024-12-26)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/evrimai/python-client/compare/v1.4.0...v1.5.0)

### Features

* **api:** update via SDK Studio ([#17](https://github.com/evrimai/python-client/issues/17)) ([6d9929d](https://github.com/evrimai/python-client/commit/6d9929d302938fd218313ddeb255fa5bae071488))

## 1.4.0 (2024-12-26)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/evrimai/python-client/compare/v1.3.0...v1.4.0)

### Features

* **api:** update via SDK Studio ([#14](https://github.com/evrimai/python-client/issues/14)) ([1733653](https://github.com/evrimai/python-client/commit/17336532dc3f942af8f428889f42c02a0f86183f))

## 1.3.0 (2024-12-26)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/evrimai/python-client/compare/v1.2.0...v1.3.0)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/evrimai/python-client/issues/11)) ([db885e8](https://github.com/evrimai/python-client/commit/db885e815107118ca29aa51913b87a11d6da28ba))

## 1.2.0 (2024-12-26)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/evrimai/python-client/compare/v1.1.0...v1.2.0)

### Features

* **api:** update via SDK Studio ([#8](https://github.com/evrimai/python-client/issues/8)) ([849dfe9](https://github.com/evrimai/python-client/commit/849dfe93bfa69955739dcc856190818a23c26c98))

## 1.1.0 (2024-12-24)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/evrimai/python-client/compare/v1.0.0...v1.1.0)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/evrimai/python-client/issues/5)) ([2a790b2](https://github.com/evrimai/python-client/commit/2a790b24ef4069baa1a9bf5821e59217f13dbadd))

## 1.0.0 (2024-12-24)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/evrimai/python-client/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/evrimai/python-client/issues/1)) ([ae010a1](https://github.com/evrimai/python-client/commit/ae010a160d0c1b0d2a4f8c436cc87b2219bad52f))
* update SDK settings ([#3](https://github.com/evrimai/python-client/issues/3)) ([70e424b](https://github.com/evrimai/python-client/commit/70e424b5e76aceff0e5536a894768870ea14977a))
